function [D, G] = discretizeFluorescenceSignal(F, varargin)
%%% Assign defuault values
params.bins = 3;
params.relativeBins = false;
params.conditioningLevel = 0;
params.highPassFilter = true;
params = parse_pv_pairs(params,varargin); 

epsilon = 1e-3; % tolerance

%%% Get the conditioning level
avgF = mean(F,2);
if(params.conditioningLevel == 0)
    [hits, pos] = hist(avgF, 100);
    [~, idx] = max(hits);
    CL = pos(idx)+0.05;
    fprintf('Discretizing at %.2f.\n', CL);
else
    CL = params.conditioningLevel;
end

G = (avgF >= CL)+1;

%%% Apply the high pass filter
if(params.highPassFilter)
    F = diff(F);
    G = G(2:end);
end

%%% Discretize the signal
D = NaN(size(F));
if(params.relativeBins)
    for i = 1:size(F, 2)
        binEdges = linspace( min(F(:, i))-epsilon, max(F(:, i))+epsilon, params.bins+1);
        for j = 1:(length(binEdges)-1)
            hits = F(:,i) >= binEdges(j) & F(:,i) < binEdges(j+1);
            D(hits, i) = j;
        end
    end        
else
    if(length(params.bins) == 1)
        binEdges = linspace(min(F(:))-epsilon, max(F(:))+epsilon, params.bins+1);
    else
        binEdges = params.bins;
    end
    for j = 1:(length(binEdges)-1)
        hits = F >= binEdges(j) & F < binEdges(j+1);
        D(hits) = j;
    end
end
